pub struct GetAudioInputAttributesResponse {
pub current_name: Option<String>,
pub current_icon: Option<String>,
}Fields
current_name: Option<String>current_icon: Option<String>Trait Implementations
Sourceimpl Clone for GetAudioInputAttributesResponse
impl Clone for GetAudioInputAttributesResponse
Sourcefn clone(&self) -> GetAudioInputAttributesResponse
fn clone(&self) -> GetAudioInputAttributesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DecodeSoapResponse for GetAudioInputAttributesResponse
impl DecodeSoapResponse for GetAudioInputAttributesResponse
Sourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.Sourceimpl<'xml> FromXml<'xml> for GetAudioInputAttributesResponse
impl<'xml> FromXml<'xml> for GetAudioInputAttributesResponse
const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<GetAudioInputAttributesResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourceimpl PartialEq for GetAudioInputAttributesResponse
impl PartialEq for GetAudioInputAttributesResponse
Sourcefn eq(&self, other: &GetAudioInputAttributesResponse) -> bool
fn eq(&self, other: &GetAudioInputAttributesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetAudioInputAttributesResponse