pub struct GetSearchCapabilitiesResponse {
pub search_caps: Option<String>,
}Fields
search_caps: Option<String>Trait Implementations
Sourceimpl Clone for GetSearchCapabilitiesResponse
impl Clone for GetSearchCapabilitiesResponse
Sourcefn clone(&self) -> GetSearchCapabilitiesResponse
fn clone(&self) -> GetSearchCapabilitiesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DecodeSoapResponse for GetSearchCapabilitiesResponse
impl DecodeSoapResponse for GetSearchCapabilitiesResponse
Sourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.Sourceimpl<'xml> FromXml<'xml> for GetSearchCapabilitiesResponse
impl<'xml> FromXml<'xml> for GetSearchCapabilitiesResponse
const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<GetSearchCapabilitiesResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourceimpl PartialEq for GetSearchCapabilitiesResponse
impl PartialEq for GetSearchCapabilitiesResponse
Sourcefn eq(&self, other: &GetSearchCapabilitiesResponse) -> bool
fn eq(&self, other: &GetSearchCapabilitiesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetSearchCapabilitiesResponse