pub struct GetShareIndexInProgressResponse {
pub is_indexing: Option<bool>,
}Fields
is_indexing: Option<bool>Trait Implementations
Sourcefn clone(&self) -> GetShareIndexInProgressResponse
fn clone(&self) -> GetShareIndexInProgressResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<GetShareIndexInProgressResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourcefn eq(&self, other: &GetShareIndexInProgressResponse) -> bool
fn eq(&self, other: &GetShareIndexInProgressResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Auto Trait Implementations