pub struct GetUseAutoplayVolumeResponse {
pub use_volume: Option<bool>,
}Fields
use_volume: Option<bool>Trait Implementations
Sourceimpl Clone for GetUseAutoplayVolumeResponse
impl Clone for GetUseAutoplayVolumeResponse
Sourcefn clone(&self) -> GetUseAutoplayVolumeResponse
fn clone(&self) -> GetUseAutoplayVolumeResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetUseAutoplayVolumeResponse
impl Debug for GetUseAutoplayVolumeResponse
Sourceimpl DecodeSoapResponse for GetUseAutoplayVolumeResponse
impl DecodeSoapResponse for GetUseAutoplayVolumeResponse
Sourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.Sourceimpl<'xml> FromXml<'xml> for GetUseAutoplayVolumeResponse
impl<'xml> FromXml<'xml> for GetUseAutoplayVolumeResponse
const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<GetUseAutoplayVolumeResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourceimpl PartialEq for GetUseAutoplayVolumeResponse
impl PartialEq for GetUseAutoplayVolumeResponse
Sourcefn eq(&self, other: &GetUseAutoplayVolumeResponse) -> bool
fn eq(&self, other: &GetUseAutoplayVolumeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetUseAutoplayVolumeResponse