pub enum AlarmPlayMode {
Normal,
RepeatAll,
ShuffleNorepeat,
Shuffle,
Unspecified(String),
}Variants
Normal
RepeatAll
ShuffleNorepeat
Shuffle
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions