pub enum ButtonLockState {
On,
Off,
Unspecified(String),
}Variants
On
Off
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions