pub enum CurrentPlayMode {
Normal,
RepeatAll,
RepeatOne,
ShuffleNorepeat,
Shuffle,
ShuffleRepeatOne,
Unspecified(String),
}Variants
Normal
RepeatAll
RepeatOne
ShuffleNorepeat
Shuffle
ShuffleRepeatOne
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions