pub enum MuteChannel {
Master,
Lf,
Rf,
SpeakerOnly,
Unspecified(String),
}Variants
Master
Lf
Rf
SpeakerOnly
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions