pub enum Recurrence {
Once,
Weekdays,
Weekends,
Daily,
Unspecified(String),
}Variants
Once
Weekdays
Weekends
Daily
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions