pub enum TransportState {
Stopped,
Playing,
PausedPlayback,
Transitioning,
Unspecified(String),
}Variants
Stopped
Playing
PausedPlayback
Transitioning
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions