pub enum UnresponsiveDeviceActionType {
Remove,
TopologyMonitorProbe,
VerifyThenRemoveSystemwide,
Unspecified(String),
}Variants
Remove
TopologyMonitorProbe
VerifyThenRemoveSystemwide
Unspecified(String)
Allows passing a value that was not known at the time that this crate was generated from the available device descriptions