pub struct SetRelativeGroupVolumeResponse {
pub new_volume: Option<u16>,
}Fields
new_volume: Option<u16>Trait Implementations
Sourceimpl Clone for SetRelativeGroupVolumeResponse
impl Clone for SetRelativeGroupVolumeResponse
Sourcefn clone(&self) -> SetRelativeGroupVolumeResponse
fn clone(&self) -> SetRelativeGroupVolumeResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DecodeSoapResponse for SetRelativeGroupVolumeResponse
impl DecodeSoapResponse for SetRelativeGroupVolumeResponse
Sourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.Sourceimpl<'xml> FromXml<'xml> for SetRelativeGroupVolumeResponse
impl<'xml> FromXml<'xml> for SetRelativeGroupVolumeResponse
const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<SetRelativeGroupVolumeResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourceimpl PartialEq for SetRelativeGroupVolumeResponse
impl PartialEq for SetRelativeGroupVolumeResponse
Sourcefn eq(&self, other: &SetRelativeGroupVolumeResponse) -> bool
fn eq(&self, other: &SetRelativeGroupVolumeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetRelativeGroupVolumeResponse