pub struct SetRelativeVolumeResponse {
pub new_volume: Option<u16>,
}Fields
new_volume: Option<u16>Trait Implementations
Sourceimpl Clone for SetRelativeVolumeResponse
impl Clone for SetRelativeVolumeResponse
Sourcefn clone(&self) -> SetRelativeVolumeResponse
fn clone(&self) -> SetRelativeVolumeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetRelativeVolumeResponse
impl Debug for SetRelativeVolumeResponse
Sourceimpl DecodeSoapResponse for SetRelativeVolumeResponse
impl DecodeSoapResponse for SetRelativeVolumeResponse
Sourcefn decode_soap_xml(xml: &str) -> Result<Self>
fn decode_soap_xml(xml: &str) -> Result<Self>
xml is a complete Soap
<Envelope> element.
This method decodes and returns Self from that Envelope.Sourceimpl<'xml> FromXml<'xml> for SetRelativeVolumeResponse
impl<'xml> FromXml<'xml> for SetRelativeVolumeResponse
const KIND: Kind = ::instant_xml::Kind::Element
type Accumulator = Option<SetRelativeVolumeResponse>
fn matches(id: Id<'_>, field: Option<Id<'_>>) -> bool
fn deserialize<'cx>( into: &mut Self::Accumulator, field: &'static str, deserializer: &mut Deserializer<'cx, 'xml>, ) -> Result<(), Error>
Sourceimpl PartialEq for SetRelativeVolumeResponse
impl PartialEq for SetRelativeVolumeResponse
Sourcefn eq(&self, other: &SetRelativeVolumeResponse) -> bool
fn eq(&self, other: &SetRelativeVolumeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetRelativeVolumeResponse