pub struct SonosDevice { /* private fields */ }Implementations
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_av_transport(
&self,
) -> Result<EventStream<AVTransportEvent>>
pub async fn subscribe_av_transport( &self, ) -> Result<EventStream<AVTransportEvent>>
Subscribe to events from the AVTransport service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_alarm_clock(
&self,
) -> Result<EventStream<AlarmClockEvent>>
pub async fn subscribe_alarm_clock( &self, ) -> Result<EventStream<AlarmClockEvent>>
Subscribe to events from the AlarmClock service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_audio_in(&self) -> Result<EventStream<AudioInEvent>>
pub async fn subscribe_audio_in(&self) -> Result<EventStream<AudioInEvent>>
Subscribe to events from the AudioIn service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_connection_manager(
&self,
) -> Result<EventStream<ConnectionManagerEvent>>
pub async fn subscribe_connection_manager( &self, ) -> Result<EventStream<ConnectionManagerEvent>>
Subscribe to events from the ConnectionManager service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_content_directory(
&self,
) -> Result<EventStream<ContentDirectoryEvent>>
pub async fn subscribe_content_directory( &self, ) -> Result<EventStream<ContentDirectoryEvent>>
Subscribe to events from the ContentDirectory service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_device_properties(
&self,
) -> Result<EventStream<DevicePropertiesEvent>>
pub async fn subscribe_device_properties( &self, ) -> Result<EventStream<DevicePropertiesEvent>>
Subscribe to events from the DeviceProperties service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_group_management(
&self,
) -> Result<EventStream<GroupManagementEvent>>
pub async fn subscribe_group_management( &self, ) -> Result<EventStream<GroupManagementEvent>>
Subscribe to events from the GroupManagement service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_group_rendering_control(
&self,
) -> Result<EventStream<GroupRenderingControlEvent>>
pub async fn subscribe_group_rendering_control( &self, ) -> Result<EventStream<GroupRenderingControlEvent>>
Subscribe to events from the GroupRenderingControl service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_ht_control(&self) -> Result<EventStream<HTControlEvent>>
pub async fn subscribe_ht_control(&self) -> Result<EventStream<HTControlEvent>>
Subscribe to events from the HTControl service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_music_services(
&self,
) -> Result<EventStream<MusicServicesEvent>>
pub async fn subscribe_music_services( &self, ) -> Result<EventStream<MusicServicesEvent>>
Subscribe to events from the MusicServices service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_queue(&self) -> Result<EventStream<QueueEvent>>
pub async fn subscribe_queue(&self) -> Result<EventStream<QueueEvent>>
Subscribe to events from the Queue service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_rendering_control(
&self,
) -> Result<EventStream<RenderingControlEvent>>
pub async fn subscribe_rendering_control( &self, ) -> Result<EventStream<RenderingControlEvent>>
Subscribe to events from the RenderingControl service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_system_properties(
&self,
) -> Result<EventStream<SystemPropertiesEvent>>
pub async fn subscribe_system_properties( &self, ) -> Result<EventStream<SystemPropertiesEvent>>
Subscribe to events from the SystemProperties service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_virtual_line_in(
&self,
) -> Result<EventStream<VirtualLineInEvent>>
pub async fn subscribe_virtual_line_in( &self, ) -> Result<EventStream<VirtualLineInEvent>>
Subscribe to events from the VirtualLineIn service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn subscribe_zone_group_topology(
&self,
) -> Result<EventStream<ZoneGroupTopologyEvent>>
pub async fn subscribe_zone_group_topology( &self, ) -> Result<EventStream<ZoneGroupTopologyEvent>>
Subscribe to events from the ZoneGroupTopology service on this device
Sourceimpl SonosDevice
impl SonosDevice
Sourcepub async fn from_ip(addr: Ipv4Addr) -> Result<Self>
pub async fn from_ip(addr: Ipv4Addr) -> Result<Self>
Constructs a SonosDevice from the supplied IP Address. Validates that the device is actually a Sonos device before returning successfully.
Sourcepub async fn for_room(room_name: &str) -> Result<Self>
pub async fn for_room(room_name: &str) -> Result<Self>
Resolves the SonosDevice whose name is equal to the provided
name. If no matching device is found within a reasonably
short, unspecified, implementation-defined timeout, then
an Error::RoomNotFound is produced.
Sourcepub async fn from_url(url: Url) -> Result<Self>
pub async fn from_url(url: Url) -> Result<Self>
Constructs a SonosDevice from the supplied URL, which must be the device_description.xml URL for that device. Validates that the device is actually a Sonos device before returning successfully.
Sourcepub async fn get_zone_group_state(&self) -> Result<Vec<ZoneGroup>>
pub async fn get_zone_group_state(&self) -> Result<Vec<ZoneGroup>>
Returns information about the zone to which this device belongs
Sourcepub async fn queue_clear(&self) -> Result<()>
pub async fn queue_clear(&self) -> Result<()>
Clears the queue
pub async fn set_play_mode(&self, new_play_mode: CurrentPlayMode) -> Result<()>
pub async fn set_av_transport_uri( &self, uri: &str, metadata: Option<TrackMetaData>, ) -> Result<()>
pub async fn queue_prepend( &self, uri: &str, metadata: Option<TrackMetaData>, ) -> Result<AddUriToQueueResponse>
pub async fn queue_append( &self, uri: &str, metadata: Option<TrackMetaData>, ) -> Result<AddUriToQueueResponse>
pub async fn queue_browse( &self, starting_index: u32, requested_count: u32, ) -> Result<Vec<TrackMetaData>>
pub fn url(&self) -> &Url
Sourceimpl SonosDevice
impl SonosDevice
pub fn device_spec(&self) -> &DeviceSpec
pub async fn subscribe_helper<T: DecodeXml + 'static>( &self, service: &str, ) -> Result<EventStream<T>>